@@ -22,10 +22,11 @@ def sentiment(txt, arg):
     return result
 
 def transformers_sentiment(txt):
+    text = txt
     sentiment_analysis = pipeline("sentiment-analysis")
-    result = sentiment_analysis(txt)[0]
-    result = ({"Label:": result['label'], "Confidence Score:": result['score']})
-    return result
+    result = sentiment_analysis(text)[0]
+    answer = ({"Label:": result['label'], "Confidence Score:": result['score']})
+    return answer
 
 #def pos_neg_sentiment(txt):
     positive_score = sentiment_analysis.get_positive_score(txt)
